@@ -15,7 +15,7 @@ def deploy_frontend(name: str, namespace: str, label_selector: str):
         'nginx.ingress.kubernetes.io/rewrite-target': '/'
     }, labels=labels)
 
-    log2(f'Shortly, ops pod will become available at https://{app_session.host}/c3/c3/ops')
+    return f'https://{app_session.host}/c3/c3/ops'
 
 def undeploy_frontend(namespace: str, label_selector: str):
     Ingresses.delete_ingresses(namespace, label_selector=label_selector)
